summaryrefslogtreecommitdiffstats
path: root/kcontrol/randr
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-01-12 10:51:50 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-01-16 10:03:43 +0900
commita4241b7911d2e0b36edfb02f616b8b282050c0ec (patch)
tree316c9a3298857645d5da57b682fce707c8e2a907 /kcontrol/randr
parentf9d06cee3d2b4ffe415b1d52c9ad5575643a9e34 (diff)
downloadtdebase-a4241b7911d2e0b36edfb02f616b8b282050c0ec.tar.gz
tdebase-a4241b7911d2e0b36edfb02f616b8b282050c0ec.zip
Use new TQ_METHOD, TQ_SIGNAL, TQ_SLOT defines
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kcontrol/randr')
-rw-r--r--kcontrol/randr/ktimerdialog.cpp4
-rw-r--r--kcontrol/randr/tderandrapp.cpp2
-rw-r--r--kcontrol/randr/tderandrbindings.cpp2
-rw-r--r--kcontrol/randr/tderandrmodule.cpp14
-rw-r--r--kcontrol/randr/tderandrpassivepopup.cpp4
-rw-r--r--kcontrol/randr/tderandrtray.cpp40
6 files changed, 33 insertions, 33 deletions
diff --git a/kcontrol/randr/ktimerdialog.cpp b/kcontrol/randr/ktimerdialog.cpp
index 1c72b1ccc..140234a90 100644
--- a/kcontrol/randr/ktimerdialog.cpp
+++ b/kcontrol/randr/ktimerdialog.cpp
@@ -56,8 +56,8 @@ KTimerDialog::KTimerDialog( int msec, TimerStyle style, TQWidget *parent,
if ( buttonMask & Cancel )
buttonOnTimeout = Cancel;
- connect( totalTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotInternalTimeout() ) );
- connect( updateTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotUpdateTime() ) );
+ connect( totalTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotInternalTimeout() ) );
+ connect( updateTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotUpdateTime() ) );
// create the widgets
mainWidget = new QVBox( this, "mainWidget" );
diff --git a/kcontrol/randr/tderandrapp.cpp b/kcontrol/randr/tderandrapp.cpp
index e2a4b46f2..97e602496 100644
--- a/kcontrol/randr/tderandrapp.cpp
+++ b/kcontrol/randr/tderandrapp.cpp
@@ -28,7 +28,7 @@
KRandRApp::KRandRApp()
: m_tray(new KRandRSystemTray(0L, "RANDRTray"))
{
- connect(&m_eventMergingTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(handleX11ConfigChangeEvent()));
+ connect(&m_eventMergingTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(handleX11ConfigChangeEvent()));
m_tray->show();
}
diff --git a/kcontrol/randr/tderandrbindings.cpp b/kcontrol/randr/tderandrbindings.cpp
index 5df10af1f..a5ad3fe6d 100644
--- a/kcontrol/randr/tderandrbindings.cpp
+++ b/kcontrol/randr/tderandrbindings.cpp
@@ -18,7 +18,7 @@
*/
#ifndef NOSLOTS
# define DEF( name, key3, key4, fnSlot ) \
- keys->insert( name, i18n(name), TQString(), key3, key4, this, TQT_SLOT(fnSlot) )
+ keys->insert( name, i18n(name), TQString(), key3, key4, this, TQ_SLOT(fnSlot) )
#else
# define DEF( name, key3, key4, fnSlot ) \
keys->insert( name, i18n(name), TQString(), key3, key4 )
diff --git a/kcontrol/randr/tderandrmodule.cpp b/kcontrol/randr/tderandrmodule.cpp
index 39e00980d..f13a863b9 100644
--- a/kcontrol/randr/tderandrmodule.cpp
+++ b/kcontrol/randr/tderandrmodule.cpp
@@ -100,7 +100,7 @@ KRandRModule::KRandRModule(TQWidget *parent, const char *name, const TQStringLis
screenLabel->setBuddy( m_screenSelector );
TQWhatsThis::add(m_screenSelector, i18n("The screen whose settings you would like to change can be selected using this drop-down list."));
- connect(m_screenSelector, TQT_SIGNAL(activated(int)), TQT_SLOT(slotScreenChanged(int)));
+ connect(m_screenSelector, TQ_SIGNAL(activated(int)), TQ_SLOT(slotScreenChanged(int)));
if (numScreens() <= 1)
m_screenSelector->setEnabled(false);
@@ -110,7 +110,7 @@ KRandRModule::KRandRModule(TQWidget *parent, const char *name, const TQStringLis
TQLabel *sizeLabel = new TQLabel(i18n("Screen size:"), sizeBox);
m_sizeCombo = new KComboBox(sizeBox);
TQWhatsThis::add(m_sizeCombo, i18n("The size, otherwise known as the resolution, of your screen can be selected from this drop-down list."));
- connect(m_sizeCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotSizeChanged(int)));
+ connect(m_sizeCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotSizeChanged(int)));
sizeLabel->setBuddy( m_sizeCombo );
TQHBox* refreshBox = new TQHBox(this);
@@ -118,7 +118,7 @@ KRandRModule::KRandRModule(TQWidget *parent, const char *name, const TQStringLis
TQLabel *rateLabel = new TQLabel(i18n("Refresh rate:"), refreshBox);
m_refreshRates = new KComboBox(refreshBox);
TQWhatsThis::add(m_refreshRates, i18n("The refresh rate of your screen can be selected from this drop-down list."));
- connect(m_refreshRates, TQT_SIGNAL(activated(int)), TQT_SLOT(slotRefreshChanged(int)));
+ connect(m_refreshRates, TQ_SIGNAL(activated(int)), TQ_SLOT(slotRefreshChanged(int)));
rateLabel->setBuddy( m_refreshRates );
m_rotationGroup = new TQButtonGroup(2, TQt::Horizontal, i18n("Orientation (degrees counterclockwise)"), this);
@@ -129,14 +129,14 @@ KRandRModule::KRandRModule(TQWidget *parent, const char *name, const TQStringLis
m_applyOnStartup = new TQCheckBox(i18n("Apply settings on TDE startup"), this);
topLayout->addWidget(m_applyOnStartup);
TQWhatsThis::add(m_applyOnStartup, i18n("If this option is enabled the size and orientation settings will be used when TDE starts."));
- connect(m_applyOnStartup, TQT_SIGNAL(clicked()), TQT_SLOT(setChanged()));
+ connect(m_applyOnStartup, TQ_SIGNAL(clicked()), TQ_SLOT(setChanged()));
TQHBox* syncBox = new TQHBox(this);
syncBox->layout()->addItem(new TQSpacerItem(20, 1, TQSizePolicy::Maximum));
m_syncTrayApp = new TQCheckBox(i18n("Allow tray application to change startup settings"), syncBox);
topLayout->addWidget(syncBox);
TQWhatsThis::add(m_syncTrayApp, i18n("If this option is enabled, options set by the system tray applet will be saved and loaded when TDE starts instead of being temporary."));
- connect(m_syncTrayApp, TQT_SIGNAL(clicked()), TQT_SLOT(setChanged()));
+ connect(m_syncTrayApp, TQ_SIGNAL(clicked()), TQ_SLOT(setChanged()));
topLayout->addStretch(1);
@@ -155,11 +155,11 @@ void KRandRModule::addRotationButton(int thisRotation, bool checkbox)
if (!checkbox) {
TQRadioButton* thisButton = new TQRadioButton(RandRScreen::rotationName(thisRotation), m_rotationGroup);
thisButton->setEnabled(thisRotation & currentScreen()->rotations());
- connect(thisButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotRotationChanged()));
+ connect(thisButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotRotationChanged()));
} else {
TQCheckBox* thisButton = new TQCheckBox(RandRScreen::rotationName(thisRotation), m_rotationGroup);
thisButton->setEnabled(thisRotation & currentScreen()->rotations());
- connect(thisButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotRotationChanged()));
+ connect(thisButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotRotationChanged()));
}
}
diff --git a/kcontrol/randr/tderandrpassivepopup.cpp b/kcontrol/randr/tderandrpassivepopup.cpp
index c938a31fc..b0e78087c 100644
--- a/kcontrol/randr/tderandrpassivepopup.cpp
+++ b/kcontrol/randr/tderandrpassivepopup.cpp
@@ -28,7 +28,7 @@
KRandrPassivePopup::KRandrPassivePopup( TQWidget *parent, const char *name, WFlags f )
: KPassivePopup( parent, name, f )
{
- connect( &update_timer, TQT_SIGNAL( timeout()), TQT_SLOT( slotPositionSelf()));
+ connect( &update_timer, TQ_SIGNAL( timeout()), TQ_SLOT( slotPositionSelf()));
}
KRandrPassivePopup* KRandrPassivePopup::message( const TQString &caption, const TQString &text,
@@ -95,7 +95,7 @@ bool KRandrPassivePopup::eventFilter( TQObject* o, TQEvent* e )
{
if( e->type() == TQEvent::Move && o->isWidgetType()
&& watched_widgets.contains( static_cast<TQWidget*>( o )))
- TQTimer::singleShot( 0, this, TQT_SLOT( slotPositionSelf()));
+ TQTimer::singleShot( 0, this, TQ_SLOT( slotPositionSelf()));
return false;
}
diff --git a/kcontrol/randr/tderandrtray.cpp b/kcontrol/randr/tderandrtray.cpp
index 6d44c3914..a5613eb2e 100644
--- a/kcontrol/randr/tderandrtray.cpp
+++ b/kcontrol/randr/tderandrtray.cpp
@@ -59,10 +59,10 @@ KRandRSystemTray::KRandRSystemTray(TQWidget* parent, const char *name)
, m_help(new KHelpMenu(this, TDEGlobal::instance()->aboutData(), false, actionCollection()))
{
TDEPopupMenu *help = m_help->menu();
- help->connectItem(KHelpMenu::menuHelpContents, this, TQT_SLOT(slotHelpContents()));
+ help->connectItem(KHelpMenu::menuHelpContents, this, TQ_SLOT(slotHelpContents()));
setPixmap(KSystemTray::loadIcon("randr"));
setAlignment(TQt::AlignHCenter | TQt::AlignVCenter);
- connect(this, TQT_SIGNAL(quitSelected()), this, TQT_SLOT(_quit()));
+ connect(this, TQ_SIGNAL(quitSelected()), this, TQ_SLOT(_quit()));
TQToolTip::add(this, i18n("Screen resize & rotate"));
my_parent = parent;
@@ -75,10 +75,10 @@ KRandRSystemTray::KRandRSystemTray(TQWidget* parent, const char *name)
globalKeys->setEnabled(true);
globalKeys->updateConnections();
- connect(kapp, TQT_SIGNAL(settingsChanged(int)), TQT_SLOT(slotSettingsChanged(int)));
+ connect(kapp, TQ_SIGNAL(settingsChanged(int)), TQ_SLOT(slotSettingsChanged(int)));
#if (TQT_VERSION-0 >= 0x030200) // XRANDR support
-// connect(this, TQT_SIGNAL(screenSizeChanged(int, int)), kapp->desktop(), TQT_SLOT( desktopResized()));
+// connect(this, TQ_SIGNAL(screenSizeChanged(int, int)), kapp->desktop(), TQ_SLOT( desktopResized()));
#endif
randr_display = XOpenDisplay(NULL);
@@ -98,12 +98,12 @@ KRandRSystemTray::KRandRSystemTray(TQWidget* parent, const char *name)
#ifdef WITH_TDEHWLIB
TDEHardwareDevices *hwdevices = TDEGlobal::hardwareDevices();
- connect(hwdevices, TQT_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQT_SLOT(deviceChanged(TDEGenericDevice*)));
+ connect(hwdevices, TQ_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQ_SLOT(deviceChanged(TDEGenericDevice*)));
#endif
}
/*!
* \b TQT_SLOT which called if tderandrtray is exited by the user. In this case the user
* is asked through a yes/no box if "KRandRTray should start automatically on log in" and the
* result is written to the KDE configfile.
*/
@@ -271,7 +271,7 @@ void KRandRSystemTray::contextMenuAboutToShow(TDEPopupMenu* menu)
m_screenPopups.append(subMenu);
populateMenu(subMenu);
lastIndex = menu->insertItem(i18n("Screen %1").arg(s+1), subMenu);
- connect(subMenu, TQT_SIGNAL(activated(int)), TQT_SLOT(slotScreenActivated()));
+ connect(subMenu, TQ_SIGNAL(activated(int)), TQ_SLOT(slotScreenActivated()));
}
}
@@ -293,7 +293,7 @@ void KRandRSystemTray::contextMenuAboutToShow(TDEPopupMenu* menu)
menu->setItemChecked(lastIndex, true);
}
menu->setItemEnabled(lastIndex, t_config->readBoolEntry("EnableICC", false));
- menu->connectItem(lastIndex, this, TQT_SLOT(slotColorProfileChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotColorProfileChanged(int)));
}
if (valid) {
@@ -303,10 +303,10 @@ void KRandRSystemTray::contextMenuAboutToShow(TDEPopupMenu* menu)
if (!displayProfiles.isEmpty()) {
menu->insertTitle(SmallIcon("background"), i18n("Display Profiles"));
lastIndex = menu->insertItem(SmallIcon("bookmark"), "<default>");
- menu->connectItem(lastIndex, this, TQT_SLOT(slotDisplayProfileChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotDisplayProfileChanged(int)));
for (TQStringList::Iterator t(displayProfiles.begin()); t != displayProfiles.end(); ++t) {
lastIndex = menu->insertItem(SmallIcon("bookmark"), *t);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotDisplayProfileChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotDisplayProfileChanged(int)));
}
}
}
@@ -314,17 +314,17 @@ void KRandRSystemTray::contextMenuAboutToShow(TDEPopupMenu* menu)
menu->insertTitle(SmallIcon("randr"), i18n("Global Configuration"));
TDEAction *actColors = new TDEAction( i18n( "Configure Displays..." ),
- SmallIconSet( "configure" ), TDEShortcut(), this, TQT_SLOT( slotDisplayConfig() ),
+ SmallIconSet( "configure" ), TDEShortcut(), this, TQ_SLOT( slotDisplayConfig() ),
actionCollection() );
actColors->plug( menu );
// TDEAction *actPrefs = new TDEAction( i18n( "Configure Display..." ),
-// SmallIconSet( "configure" ), TDEShortcut(), this, TQT_SLOT( slotPrefs() ),
+// SmallIconSet( "configure" ), TDEShortcut(), this, TQ_SLOT( slotPrefs() ),
// actionCollection() );
// actPrefs->plug( menu );
TDEAction *actSKeys = new TDEAction( i18n( "Configure Shortcut Keys..." ),
- SmallIconSet( "configure" ), TDEShortcut(), this, TQT_SLOT( slotSKeys() ),
+ SmallIconSet( "configure" ), TDEShortcut(), this, TQ_SLOT( slotSKeys() ),
actionCollection() );
actSKeys->plug( menu );
@@ -442,7 +442,7 @@ void KRandRSystemTray::populateMenu(TDEPopupMenu* menu)
menu->setItemChecked(lastIndex, true);
menu->setItemParameter(lastIndex, highestIndex);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotResolutionChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotResolutionChanged(int)));
}
delete [] sizeSort;
sizeSort = 0L;
@@ -460,7 +460,7 @@ void KRandRSystemTray::populateMenu(TDEPopupMenu* menu)
menu->setItemChecked(lastIndex, true);
menu->setItemParameter(lastIndex, 1 << i);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotOrientationChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotOrientationChanged(int)));
}
}
}
@@ -478,7 +478,7 @@ void KRandRSystemTray::populateMenu(TDEPopupMenu* menu)
menu->setItemChecked(lastIndex, true);
menu->setItemParameter(lastIndex, i);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotRefreshRateChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotRefreshRateChanged(int)));
}
}
@@ -764,7 +764,7 @@ void KRandRSystemTray::addOutputMenu(TDEPopupMenu* menu)
lastIndex = menu->insertItem(i18n("%1 (Active)").arg(output_name));
menu->setItemChecked(lastIndex, true);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotOutputChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotOutputChanged(int)));
menu->setItemParameter(lastIndex, i);
connected_displays++;
@@ -786,7 +786,7 @@ void KRandRSystemTray::addOutputMenu(TDEPopupMenu* menu)
lastIndex = menu->insertItem(i18n("%1 (Connected, Inactive)").arg(output_name));
menu->setItemChecked(lastIndex, false);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotOutputChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotOutputChanged(int)));
menu->setItemParameter(lastIndex, i);
connected_displays++;
@@ -809,7 +809,7 @@ void KRandRSystemTray::addOutputMenu(TDEPopupMenu* menu)
lastIndex = menu->insertItem(i18n("%1 (Disconnected, Inactive)").arg(output_name));
menu->setItemChecked(lastIndex, false);
menu->setItemEnabled(lastIndex, false);
- menu->connectItem(lastIndex, this, TQT_SLOT(slotOutputChanged(int)));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotOutputChanged(int)));
menu->setItemParameter(lastIndex, i);
}
@@ -817,7 +817,7 @@ void KRandRSystemTray::addOutputMenu(TDEPopupMenu* menu)
if (connected_displays < 2) {
menu->setItemEnabled(lastIndex, false);
}
- menu->connectItem(lastIndex, this, TQT_SLOT(slotCycleDisplays()));
+ menu->connectItem(lastIndex, this, TQ_SLOT(slotCycleDisplays()));
}
}
@@ -98,12 +98,12 @@ KRandRSystemTray::KRandRSystemTray(TQWidget* parent, const char *name)
}
/*!
- * \b TQT_SLOT which called if tderandrtray is exited by the user. In this case the user
+ * \b TQ_SLOT which called if tderandrtray is exited by the user. In this case the user
* is asked through a yes/no box if "KRandRTray should start automatically on log in" and the
* result is written to the KDE configfile.